@@ -1,4 +1,4 @@
-import tkinter,pytools.math,copy
+import tkinter,SomeToolspbc.math,copy
 
 
 class windows:
